pub fn parse_normalized_transcript_file(
path: impl AsRef<Path>,
options: SubtitleNormalizationOptions,
) -> Result<TranscriptionContract>Expand description
Parses and normalizes a transcript file into the stable transcript contract.
pub fn parse_normalized_transcript_file(
path: impl AsRef<Path>,
options: SubtitleNormalizationOptions,
) -> Result<TranscriptionContract>Parses and normalizes a transcript file into the stable transcript contract.