pub fn parse_transcript_file(
path: impl AsRef<Path>,
) -> Result<TranscriptionResult>Expand description
Parses a transcript file by inferring the format from its extension.
pub fn parse_transcript_file(
path: impl AsRef<Path>,
) -> Result<TranscriptionResult>Parses a transcript file by inferring the format from its extension.